pub enum BlockStructure {
Rectangular,
TriangularLower,
StrictTriangularLower,
UnitTriangularLower,
TriangularUpper,
StrictTriangularUpper,
UnitTriangularUpper,
}Expand description
Describes the parts of the matrix that must be accessed.
Variants
Rectangular
The full matrix is accessed.
TriangularLower
The lower triangular half (including the diagonal) is accessed.
StrictTriangularLower
The lower triangular half (excluding the diagonal) is accessed.
UnitTriangularLower
The lower triangular half (excluding the diagonal, which is assumed to be equal to
1.0) is accessed.
TriangularUpper
The upper triangular half (including the diagonal) is accessed.
StrictTriangularUpper
The upper triangular half (excluding the diagonal) is accessed.
UnitTriangularUpper
The upper triangular half (excluding the diagonal, which is assumed to be equal to
1.0) is accessed.
Implementations