from_slice_mut

Function from_slice_mut 

pub fn from_slice_mut<'a, E: Entity>(
    slice: GroupFor<E, &'a mut [E::Unit]>,
) -> RowMut<'a, E>
Creates a RowMut from slice views over the row vector data, The result has the same number of columns as the length of the input slice.