pub fn from_slice<'a, E: Entity>( slice: GroupFor<E, &'a [E::Unit]>, ) -> RowRef<'a, E>
Creates a RowRef from slice views over the row vector data, The result has the same number of columns as the length of the input slice.
RowRef