pub unsafe trait MatIndex<'a, _Outlives = &'a Self>: MaybeContiguous {
type Item;
// Required methods
unsafe fn get_unchecked(&'a mut self, index: Self::Index) -> Self::Item;
unsafe fn get_from_slice_unchecked(
slice: &'a mut Self::Slice,
idx: usize,
) -> Self::Item;
fn is_contiguous(&self) -> bool;
fn preferred_layout(&self) -> Self::LayoutTransform;
fn with_layout(self, layout: Self::LayoutTransform) -> Self;
}Expand description
Zipped matrix views.
Required Associated Types
Required Methods
Sourceunsafe fn get_unchecked(&'a mut self, index: Self::Index) -> Self::Item
unsafe fn get_unchecked(&'a mut self, index: Self::Index) -> Self::Item
Get the item at the given index, skipping bound checks.
Sourceunsafe fn get_from_slice_unchecked(
slice: &'a mut Self::Slice,
idx: usize,
) -> Self::Item
unsafe fn get_from_slice_unchecked( slice: &'a mut Self::Slice, idx: usize, ) -> Self::Item
Get the item at the given slice position, skipping bound checks.
Sourcefn is_contiguous(&self) -> bool
fn is_contiguous(&self) -> bool
Checks if the zipped matrices are contiguous.
Sourcefn preferred_layout(&self) -> Self::LayoutTransform
fn preferred_layout(&self) -> Self::LayoutTransform
Computes the preferred iteration layout of the matrices.
Sourcefn with_layout(self, layout: Self::LayoutTransform) -> Self
fn with_layout(self, layout: Self::LayoutTransform) -> Self
Applies the layout transformation to the matrices.
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".